@@ -1,34 +1,19 @@
-// $Revision: #15 $$Date: 2004/01/27 $$Author: wsnyder $
+// $Revision: #16 $$Date: 2004/07/19 $$Author: ws150726 $
 // DESCRIPTION: SystemPerl: Example main()
 //
 // Copyright 2001-2004 by Wilson Snyder.  This program is free software;
 // you can redistribute it and/or modify it under the terms of either the GNU
 // General Public License or the Perl Artistic License.
 
+#include <sys/stat.h>
+#include <sys/types.h>
+
 #include <systemperl.h>
 #include "sp_log.h"
 #include "ExBench.h"
 #include "SpTraceVcd.h"
 #include "SpCoverage.h"
 
-static FILE* sp_Coverage_Fp = NULL;
-
-static void sp_coverage_write (const char* filename) {
-    // Write the coverage file
-    sp_Coverage_Fp = fopen(filename,"w");
-    if (!sp_Coverage_Fp) { cerr<<"Can't Write "<<filename<<endl; abort(); }
-    SpFunctorNamed::call("coverageWrite");   // Will invoke above sp_coverage_data's
-    fprintf(sp_Coverage_Fp,"\n1;\n");	// OK exit status for perl
-    fclose(sp_Coverage_Fp);
-    sp_Coverage_Fp = NULL;
-}
-
-void sp_coverage_data (const char *hier, const char *what, const char *file, int lineno, uint32_t data) {
-    // Needed if any SP_COVERAGE statements in the model
-    fprintf(sp_Coverage_Fp,"Coverage::line('%s','%s','%s',%d,%6d);\n",
-	    what,hier,file,lineno,data);
-}
-
 int sc_main (int argc, char *argv[]) {
     // Simulation logfile
     sp_log_file splog;
@@ -75,7 +60,8 @@ int sc_main (int argc, char *argv[]) {
     SpTraceVcd::flush_all();
 
     // Coverage
-    sp_coverage_write("coverage.pl");
+    mkdir("logs", 0777);
+    SpCoverage::write();  // Writes logs/coverage.pl
 
     return (0);
 }
